@@ -14,12 +14,14 @@ use reqwest::Url;
 use serde::{Deserialize, Deserializer};
 use std::borrow::Cow;
 use std::cmp::Ordering;
+use std::collections::HashSet;
 use std::error::Error;
 use std::fs;
 use std::io::BufReader;
 use std::path::{Path, PathBuf};
 use std::time::Instant;
 use structopt::StructOpt;
+use truncatable::Truncatable;
 use tvrank::imdb::{Imdb, ImdbQueryType, ImdbTitle, ImdbTitleId};
 use tvrank::Res;
 use ui::create_progress_spinner;
@@ -32,6 +34,8 @@ enum TvRankErr {
   CacheDir,
   #[display(fmt = "Invalid `tvrank.json` file")]
   InvalidTitleInfo,
+  #[display(fmt = "Empty set of keywords")]
+  NoKeywords,
 }
 
 impl TvRankErr {
@@ -42,6 +46,10 @@ impl TvRankErr {
   fn invalid_title_info<T>() -> Res<T> {
     Err(Box::new(TvRankErr::InvalidTitleInfo))
   }
+
+  fn no_keywords<T>() -> Res<T> {
+    Err(Box::new(TvRankErr::NoKeywords))
+  }
 }
 
 impl Error for TvRankErr {}
@@ -204,10 +212,10 @@ fn create_output_row_for_title(title: &ImdbTitle, imdb_url: &Url) -> Res<Row> {
 
   let mut row = Row::new(vec![]);
 
-  row.add_cell(Cell::new(title.primary_title()));
+  row.add_cell(Cell::new(&Truncatable::from(title.primary_title()).truncate(60)));
 
   if let Some(original_title) = title.original_title() {
-    row.add_cell(Cell::new(original_title));
+    row.add_cell(Cell::new(&Truncatable::from(original_title).truncate(60)));
   } else {
     row.add_cell(Cell::new(""));
   }
@@ -314,12 +322,20 @@ fn imdb_single_title<'a>(title: &str, imdb: &'a Imdb, imdb_url: &Url, sort_by_ye
     )?;
   } else {
     debug!("Going to use `{}` as keywords for search query", title);
-    let mut keywords = title
-      .split_whitespace()
-      .filter(|&keyword| keyword.len() > 2)
-      .collect::<Vec<_>>();
-    keywords.sort_unstable();
-    keywords.dedup();
+    let keywords_set: HashSet<_> = title.split_whitespace().map(|kw| kw.to_lowercase()).collect();
+    let keywords_set = if keywords_set.is_empty() {
+      return TvRankErr::no_keywords();
+    } else if keywords_set.len() > 1 {
+      keywords_set
+        .into_iter()
+        .filter(|keyword| keyword.len() > 1)
+        .collect::<HashSet<_>>()
+    } else {
+      keywords_set
+    };
+
+    let mut keywords = vec![];
+    keywords.extend(keywords_set.iter().map(<String as AsRef<str>>::as_ref));
     debug!("Keywords: {:?}", keywords);
 
     movies_results.extend(imdb.by_keywords(&keywords, ImdbQueryType::Movies));
